@@ -5,8 +5,7 @@ import textwrap
 
 import semver
 
-from suite_py.lib import logger
-from suite_py.lib import metrics
+from suite_py.lib import logger, metrics
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.drone_handler import DroneHandler
 from suite_py.lib.handler.git_handler import GitHandler
