@@ -4,8 +4,7 @@ import re
 
 from pptree import Node, print_tree
 
-from suite_py.lib import logger
-from suite_py.lib import metrics
+from suite_py.lib import logger, metrics
 from suite_py.lib.handler.aws_handler import Aws
 
 
