@@ -3,17 +3,15 @@ import sys
 
 import requests
 
-from suite_py.lib import logger
-from suite_py.lib import metrics
-from suite_py.lib.handler.captainhook_handler import CaptainHook
+from suite_py.lib import logger, metrics
 
 
 class ProjectLock:
-    def __init__(self, project, env, action, config, tokens):
+    def __init__(self, project, env, action, captainhook):
         self._project = project
         self._env = _parse_env(env)
         self._action = action
-        self._captainhook = CaptainHook(config, tokens=tokens)
+        self._captainhook = captainhook
 
     @metrics.command("manage-project-lock")
     def run(self):
