@@ -6,11 +6,9 @@ import semver
 from halo import Halo
 
 from suite_py.commands import common
-from suite_py.lib import logger
-from suite_py.lib import metrics
+from suite_py.lib import logger, metrics
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
-from suite_py.lib.handler.captainhook_handler import CaptainHook
 from suite_py.lib.handler.changelog_handler import ChangelogHandler
 from suite_py.lib.handler.drone_handler import DroneHandler
 from suite_py.lib.handler.git_handler import GitHandler
@@ -21,7 +19,7 @@ from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 
 class Release:
     # pylint: disable=too-many-instance-attributes
-    def __init__(self, action, project, config, tokens, flags=None):
+    def __init__(self, action, project, captainhook, config, tokens, flags=None):
         self._action = action
         self._project = project
         self._flags = flags
@@ -29,7 +27,7 @@ class Release:
         self._tokens = tokens
         self._changelog_handler = ChangelogHandler()
         self._youtrack = YoutrackHandler(config, tokens)
-        self._captainhook = CaptainHook(config)
+        self._captainhook = captainhook
         self._github = GithubHandler(tokens)
         self._repo = self._github.get_repo(project)
         self._git = GitHandler(project, config)
