@@ -78,9 +78,7 @@ class Config:
             ) as cache_file:
                 return json.load(cache_file)
         except Exception:
-            logger.error(
-                f"I couldn't find any cached version for the key {key}. Turn on the VPN."
-            )
+            logger.debug(f"I couldn't find any cached version for the key {key}.")
             return ""
             # sys.exit(-1)
 
