@@ -1,21 +1,24 @@
 # -*- encoding: utf-8 -*-
-import sys
-
 import requests
 
-from suite_py.lib import logger
 from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler.okta_handler import Okta
+from suite_py.__version__ import __version__
+
+
+class UnauthorizedError(Exception):
+    def __init__(self) -> None:
+        super().__init__("Unauthorized with captainhook")
 
 
 class CaptainHook:
-    def __init__(self, config, tokens=None):
+    _okta: Okta
+    _github: GithubHandler
+
+    def __init__(self, config, okta: Okta, tokens=None):
         self._baseurl = config.user["captainhook_url"]
         self._timeout = config.user["captainhook_timeout"]
-        self._okta_base_url = config.okta["base_url"]
-        self._okta_token = config.get_cache(f"{self._okta_base_url}_token")
-        self._headers = {
-            "Authorization": f"Bearer {self._okta_token}",
-        }
+        self._okta = okta
 
         if tokens is not None:
             self._github = GithubHandler(tokens)
@@ -60,58 +63,39 @@ class CaptainHook:
         self.send_post_request("/suite_py/metrics/", json=metrics).raise_for_status()
 
     def send_post_request(self, endpoint, data=None, json=None):
-        try:
-            r = requests.post(
-                f"{self._baseurl}{endpoint}",
-                headers=self._headers,
-                data=data,
-                json=json,
-                timeout=self._timeout,
-            )
+        r = requests.post(
+            f"{self._baseurl}{endpoint}",
+            headers=self._headers(),
+            data=data,
+            json=json,
+            timeout=self._timeout,
+        )
 
-            return self._response(r)
-        except Exception as e:
-            logger.error(
-                "Unable to contact Captainhook, are you logged in/using the VPN?"
-            )
-            raise e
+        return self._response(r)
 
     def send_put_request(self, endpoint, data=None, json=None):
-        try:
-            r = requests.put(
-                f"{self._baseurl}{endpoint}",
-                headers=self._headers,
-                data=data,
-                json=json,
-                timeout=self._timeout,
-            )
+        r = requests.put(
+            f"{self._baseurl}{endpoint}",
+            headers=self._headers(),
+            data=data,
+            json=json,
+            timeout=self._timeout,
+        )
 
-            return self._response(r)
-        except Exception as e:
-            logger.error(
-                "Unable to contact Captainhook, are you logged in/using the VPN?"
-            )
-            raise e
+        return self._response(r)
 
     def send_get_request(self, endpoint):
-        try:
-            r = requests.get(
-                f"{self._baseurl}{endpoint}",
-                headers=self._headers,
-                timeout=(2, self._timeout),
-            )
+        r = requests.get(
+            f"{self._baseurl}{endpoint}",
+            headers=self._headers(),
+            timeout=(2, self._timeout),
+        )
 
-            return self._response(r)
-        except Exception as e:
-            logger.error(
-                "Unable to contact Captainhook, are you logged in/using the VPN?"
-            )
-            raise e
+        return self._response(r)
 
     def _response(self, response):
         if response.status_code == 401:
-            logger.error("Unauthorized. Are you logged in?")
-            sys.exit(-1)
+            raise UnauthorizedError()
 
         return response
 
@@ -120,3 +104,10 @@ class CaptainHook:
 
     def _get_user(self):
         return self._github.get_user().login
+
+    def _headers(self):
+        id_token = self._okta.get_id_token()
+        return {
+            "User-Agent": f"suite-py/{__version__}",
+            "Authorization": f"Bearer {id_token}",
+        }
