@@ -149,6 +149,7 @@ class Tokens:
 
     def edit(self, service, token):
         self._tokens[service] = token
+        self.save()
 
     def keys(self):
         return self._tokens.keys()
@@ -164,3 +165,6 @@ class Tokens:
     @property
     def drone(self):
         return self._tokens["drone"]
+
+    def okta(self):
+        return self._tokens.get("okta", {})
